Examples
********

.. toctree::
   :maxdepth: 1

   interface

All shown examples are also available as ipython notebooks in ``ismn/docs/examples``.
Data used in the examples is NOT provided here, and must be downloaded from `ISMN <https://ismn.earth/en/>`_.